@@ -34,15 +34,15 @@ backtransf <- function(x, sm, value, n, warn = FALSE) {
     sel0 <- res[!is.na(res)] < 0 & value == "lower"
     sel1 <- res[!is.na(res)] > 1 & value == "upper"
     ##
-    if (warn & any(sel0 | sel1))
+    if (warn & any(sel0 | sel1, na.rm = TRUE))
       warning("Negative value for ",
               if (length(x) > 1) "at least one ",
               if (value == "lower") "lower confidence limit of raw proportions.\n  Lower confidence limit set to 0.",
               if (value == "upper") "upper confidence limit of raw proportions.\n  Upper confidence limit set to 1.",
               sep = "")
-    if (any(sel0) & value == "lower")
+    if (any(sel0, na.rm = TRUE) & value == "lower")
       res[sel0] <- 0
-    else if (any(sel1) & value == "upper")
+    else if (any(sel1, na.rm = TRUE) & value == "upper")
       res[sel1] <- 1
   }
   
@@ -50,27 +50,27 @@ backtransf <- function(x, sm, value, n, warn = FALSE) {
     sel0 <- res[!is.na(res)] < 0 & value == "lower"
     sel1 <- res[!is.na(res)] > 1 & value == "upper"
     ##
-    if (warn & any(sel0 | sel1))
+    if (warn & any(sel0 | sel1, na.rm = TRUE))
       warning("Negative value for ",
               if (length(x) > 1) "at least one ",
               if (value == "lower") "lower confidence limit using log transformation for proportions.\n  Lower confidence limit set to 0.",
               if (value == "upper") "upper confidence limit using log transformation for proportions.\n  Upper confidence limit set to 1.",
               sep = "")
-    if (any(sel0) & value == "lower")
+    if (any(sel0, na.rm = TRUE) & value == "lower")
       res[sel0] <- 0
-    else if (any(sel1) & value == "upper")
+    else if (any(sel1, na.rm = TRUE) & value == "upper")
       res[sel1] <- 1
   }
   
   if (sm == "IR") {
     sel0 <- res[!is.na(res)] < 0 & value == "lower"
     ##
-    if (warn & any(sel0))
+    if (warn & any(sel0, na.rm = TRUE))
       warning("Negative value for ",
               if (length(x) > 1) "at least one ",
               if (value == "lower") "lower confidence limit of incidence rates.\n  Lower confidence limit set to 0.",
               sep = "")
-    if (any(sel0) & value == "lower")
+    if (any(sel0, na.rm = TRUE) & value == "lower")
       res[sel0] <- 0
   }
 
